@@ -2,6 +2,7 @@ from pathlib import Path
 
 import click
 
+from timething import align as timething_align
 from timething import cutter, dataset, job, text, utils  # type: ignore
 
 
@@ -58,6 +59,13 @@ def cli():
     show_default=True,
     help="Number of shingles to use for the partition score",
 )
+@click.option(
+    "--offline",
+    type=bool,
+    default=False,
+    show_default=True,
+    help="Offline mode",
+)
 def align(
     language: str,
     metadata: str,
@@ -66,6 +74,7 @@ def align(
     n_workers: int,
     use_gpu: bool,
     k_shingles: int,
+    offline: bool,
 ):
     """Align text transcripts with audio.
 
@@ -76,7 +85,7 @@ def align(
     """
 
     # retrieve the config for the given language
-    cfg = utils.load_config(language, k_shingles)
+    cfg = utils.load_config(language, k_shingles, local_files_only=offline)
 
     # construct the dataset
     ds = dataset.SpeechDataset(Path(metadata), cfg.sampling_rate)
@@ -86,10 +95,10 @@ def align(
     j = job.Job(
         cfg,
         ds,
-        Path(alignments_dir),
         batch_size=batch_size,
         n_workers=n_workers,
         gpu=use_gpu,
+        output_path=Path(alignments_dir),
     )
 
     # construct the generic model text cleaner
@@ -163,5 +172,27 @@ def recut(
     )
 
 
+@cli.command()
+@click.option(
+    "--language",
+    default="english",
+    show_default=True,
+    help="Key in timething/models.yaml.",
+)
+def download(language: str):
+    """Downloads a speech recognition model and puts it in the cache dir.
+
+    Timething will download the language model you need on demand. In some
+    cases, you may want to cache the model before though.
+    """
+
+    # retrieve the config for the given language
+    cfg = utils.load_config(language)
+
+    # download
+    click.echo("dowloading speech recognition model...")
+    timething_align.Aligner.build("cpu", cfg)
+
+
 if __name__ == "__main__":
     cli(prog_name="timething")  # type: ignore
