@@ -1,3 +1,4 @@
+import typing
 from pathlib import Path
 
 import torch
@@ -8,18 +9,17 @@ from timething import align, dataset, utils  # type: ignore
 
 
 class Job:
-    """
-    An alignment job
+    """An alignment job.
     """
 
     def __init__(
         self,
         cfg: align.Config,
         ds: Dataset,
-        output_path: Path,
         batch_size: int,
         n_workers: int,
         gpu: bool,
+        output_path: typing.Optional[Path],
     ):
         self.cfg = cfg
         self.device = "cuda" if torch.cuda.is_available() and gpu else "cpu"
@@ -35,9 +35,14 @@ class Job:
 
     def run(self):
         total = len(self.loader)
+        ret = []
         for xs, ys, ys_original, ids in tqdm(self.loader, total=total):
             alignments = self.aligner.align((xs, ys, ys_original, ids))
+            ret.append(alignments)
 
             # write the alignments
-            for i, id in enumerate(ids):
-                utils.write_alignment(self.output_path, id, alignments[i])
+            if self.output_path:
+                for i, id in enumerate(ids):
+                    utils.write_alignment(self.output_path, id, alignments[i])
+
+        return ret
